# Tutorials

Here there is a number of small tutorials to get you going with SatMAD. You can find the interactive Jupyter notebook versions of these at the [project repository](https://github.com/egemenimre/satmad/tree/master/docs/tutorials).

In addition to the relatively simple tutorials in this section, there is a repository of how-to guides to solve common real world problems and detailed analyses on specific topics in a dedicated project called SatMAD Applications, [available at Github as Jupyter notebooks](https://github.com/egemenimre/satmad_applications) and [in plain document format](https://satmad-applications.readthedocs.io/).

```{toctree} 
---
maxdepth: 1
---
tutorials/satmad_first_steps.ipynb
tutorials/numerical_prop_1.ipynb
tutorials/numerical_prop_2.ipynb
tutorials/sso_analysis.ipynb
```
